Crate backus_naur_form_parser_and_compiler

Crate backus_naur_form_parser_and_compiler 

Re-exports

pub use backus_naur_form::symbol::Symbol;
pub use backus_naur_form::token::non_terminal_token::NonTerminalToken;
pub use backus_naur_form::token::TerminalToken;
pub use backus_naur_form::token::Token;
pub use backus_naur_form::BackusNaurForm;

Modules

backus_naur_form
Contains everything relevant for the backus naur form, such as the creation of it and the tokenization aswell as possible compilation after the tokenization. This module contains the necessary functions to symbolize strings (turn a string into a AST that consists of non terminal symbols). and the necessary functions to compile those symbolized strings (turn a AST into another string).

Macros

backus_naur_form
Used to create BackusNaurForms declaratively.
Following things need to be specified: